## 0.33.0.8 (2023-02-24)

Fix some typos in comments (#9802)

## 0.33.0.7 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.33.0.6 (2023-02-09)

Use `_typeshed.FileDescriptorOrPath` in stubs (#9695)

## 0.33.0.5 (2023-02-07)

Enable flake8-pyi's Y037 (#9686)

## 0.33.0.4 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 0.33.0.3 (2023-01-26)

python-xlib: remove workaround for pytype (#9590)

## 0.33.0.2 (2023-01-16)

`Xlib`: Import `Pattern` from `re`, not `typing` (#9544)

Refs https://github.com/PyCQA/flake8-pyi/pull/324

## 0.33.0.1 (2023-01-03)

Re-enable NQA102 (#9426)

re-enable NQA102

## 0.33.0.0 (2022-12-28)

Bump python-xlib to 0.33 (#9420)

## 0.32.0.1 (2022-12-07)

3rd-party stubtest: run on Python 3.10 (#9342)

## 0.32.0.0 (2022-11-30)

Added complete Xlib stubs (#9279)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

